class TrieNode {
  children: Map<string, TrieNode>;
  isEndOfWord: boolean;
  constructor() {
    this.children = new Map<string, TrieNode>();
    this.isEndOfWord = false;
  }
}

class Trie {
  root: TrieNode;
  constructor(inputs: string[] = []) {
    this.root = new TrieNode();
    for (const item of inputs) {
      this.insert(item);
    }
  }

  insert(word: string) {
    let node = this.root;
    for (const char of word) {
      if (!node.children.has(char)) {
        node.children.set(char, new TrieNode());
      }
      node = node.children.get(char)!;
    }
    node.isEndOfWord = true;
  }

  startsWith(word: string) {
    let node = this.root;
    for (const char of word) {
      if (!node.children.has(char)) {
        return false;
      }
      node = node.children.get(char)!;
      if (node.isEndOfWord) {
        return true;
      }
    }
    return true;
  }
}
const trie = new Trie([
  "#drcl",
  "10 erste male",
  "a couple of cuckoos",
  "ab sofort schwester!",
  "adou",
  "after school",
  "alice in borderland",
  "alice und die halbbluthexe",
  "all you want, whenever you want",
  "and then i know love",
  "and then i love you",
  "angels of death",
  "anyway, i love you",
  "arifureta - der kampf zurück in meine welt",
  "aristia",
  "assassin's creed",
  "asterix",
  "auf und ab",
  "bakemonogatari",
  "barakamon",
  "beast after school",
  "berserk",
  "birds of shangri-la",
  "bitter playmate",
  "black butler",
  "bloody bites at boarding school",
  "blue eye lie",
  "boruto",
  "café liebe",
  "canis",
  "charon",
  "cheering up in the underworld",
  "cold - die kreatur",
  "colette beschließt zu sterben",
  "crossing borders",
  "d.n. angel",
  "dahlia lässt den kopf nicht hängen",
  "das band der unterwelt",
  "das kind, das ich in meinen träumen sah",
  "das magische baumhaus",
  "das opfer des",
  "dead mount death play",
  "deadlock",
  "definitely love",
  "dem himmel zu fern",
  "der dieb und das biest",
  "der fuchs und der kleine tanuki",
  "der geschmack nach melone",
  "der sommer",
  "der stärkste held mit dem mal der schwäche",
  "die for me, my darling",
  "die hexe und das biest",
  "die hexe und ihr drache",
  "die hohe",
  "die mit dem teufel tanzt",
  "die nacht hinter dem dreiecksfenster",
  "die rachsüchtige",
  "die schokohexe ",
  "die tänzerin des königs",
  "die walkinder",
  "don't lie to me",
  "dr. stone",
  "drache &amp; chamäleon",
  "drachenregen",
  "edens zero",
  "ein bund fürs leben",
  "ein landei aus dem dorf vor dem letzten dungeon sucht das abenteuer in der stadt",
  "ein zeichen der zuneigung",
  "elainas reise",
  "elden ring kapitel",
  "elden ring",
  "eliana",
  "enceladus - die graphic novel",
  "fairy tail",
  "fairy tale",
  "fangirl",
  "final fantasy",
  "fire force",
  "flüster mir ein liebeslied",
  "folge den wolken nach nord-nordwest",
  "from bottom to lover",
  "gachiakuta",
  "galerie einer neuen galaxis",
  "gannibal",
  "gespielte liebe",
  "gestatten, ich bin's",
  "go! go! loser ranger",
  "goblin slayer!",
  "hallo, ich bin eine hexe und mein schwarm wünscht sich einen liebestrank von mir",
  "harahara sensei",
  "himmelblaue zeiten",
  "hiraeth",
  "how to train a newbie",
  "human extinction",
  "hunter x hunter",
  "i hear the sunspot",
  "i'll be here for you",
  "ich habe 300 jahre lang",
  "ich täuschte amnesie vor, um meinen verlobten loszuwerden",
  "im schatten der fabriken",
  "in/spectre",
  "insomniacs",
  "interviews mit monster-mädchen",
  "is love the answer?",
  "isekai office worker",
  "jagaaan",
  "jealousy blinds love",
  "just mary",
  "kabukicho bad trip",
  "kakegurui twin",
  "kampf der verführergiganten",
  "kijin gentosho",
  "kleiner tai &amp; omi sue",
  "konosuba",
  "kreative kurzaufgaben",
  "küsse",
  "lass meine hand nicht los",
  "lieb mich noch, bevor du stirbst",
  "liebe ist (k)ein wettkampf",
  "lightning and romance",
  "lone wolf &amp; cub master",
  "lonely castle in the mirror",
  "love escape",
  "lullaby of the dawn",
  "madk",
  "manga for success",
  "manga love story",
  "manga! manga!",
  "meet me online",
  "megumi &amp; tsugumi",
  "mein isekai-leben",
  "mein nachbar",
  "mein untergang",
  "meine arbeit als missionar in einer gottlosen welt",
  "meine wiedergeburt als schleim in einer anderen welt",
  "merit und der ägyptische",
  "midnight scandal sex",
  "minato's coin laundry",
  "mord im dekagon",
  "moriarty the patriot",
  "mpd psycho",
  "mr nobody",
  "murciélago",
  "mushoku tensei",
  "my dear curse-casting vampiress",
  "my genderless boyfriend",
  "my hero academia",
  "my love will last till the end of time",
  "my senpai is annoying",
  "my younger senpai",
  "nana &amp; kaoru: das letzte jahr",
  "never love an egoist",
  "nina - die sterne sind dein schicksal",
  "one piece",
  "one room dog",
  "overlord",
  "penelope",
  "peter grill",
  "planetes perfect edition",
  "planetes perfect",
  "pluto: urasawa x tezuka",
  "prince never give up",
  "prinz freya",
  "radiant",
  "raeliana",
  "re:zero",
  "real account",
  "red apple",
  "relife",
  "religiöse helden",
  "rental girlfriend",
  "requiem of the rose king",
  "ripper",
  "rosen blood",
  "saint seiya",
  "saraba, yoki hi",
  "saturn return",
  "schattenprinzessin des drachenkönigs",
  "servamp, band",
  "seven deadly sins",
  "severed",
  "shaman king",
  "shojo nach der schule",
  "silent witch",
  "skip &amp; loafer",
  "skip beat",
  "sleeping dead",
  "smoking behind the supermarket",
  "solo leveling roman taschenbuchausgabe",
  "star wars",
  "stigmata",
  "sugar apple fairy tale",
  "suzume",
  "sword art online",
  "takopi und die sache mit dem glück",
  "teach me how to kill you",
  "teddyboys",
  "the beast must die",
  "the beginning after the end",
  "the dungeon of black company",
  "the elusive samurai",
  "the gender of mona lisa",
  "the guy she was interested in wasn't a guy at all",
  "the heroic legend of arslan",
  "the ichinose family's deadly sins",
  "the male bride",
  "the man who shattered my world",
  "the most distant love",
  "the reprise",
  "the saint's magic power is omnipotent",
  "threesome",
  "to the abandoned sacred beasts",
  "tokyo aliens",
  "tokyo revengers",
  "tokyopop",
  "too close to love",
  "touching your night",
  "touring after the apocalypse",
  "twin star",
  "undead unluck",
  "under ninja",
  "unlimited lust",
  "vampire knight",
  "veil",
  "verbotene allianz",
  "verliebt in mehr als dein gesicht",
  "victoria's electric coffin",
  "vinland saga",
  "virgin road",
  "white light ceremony",
  "wiedergeburt in maydare",
  "wind breaker",
  "wise man",
  "wistoria",
  "wolverine",
  "yakuza angel",
  "yona",
  "you're my cutie!",
  "your sweet scent",
  "yuzu - die  kleine tierärztin",
  "yuzu",
  "zombie hide sex",
]);
export { trie };
